package com.ruoyi.logistics.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.logistics.mapper.BizFinancialFeeItemsMapper;
import com.ruoyi.logistics.domain.BizFinancialFeeItems;
import com.ruoyi.logistics.service.IBizFinancialFeeItemsService;
import com.ruoyi.logistics.service.FeeItemsCacheService;

/**
 * 费用类型管理Service业务层处理
 * 
 * @author RuiJing
 * @date 2026-01-29
 */
@Service
public class BizFinancialFeeItemsServiceImpl implements IBizFinancialFeeItemsService 
{
    @Autowired
    private BizFinancialFeeItemsMapper bizFinancialFeeItemsMapper;

    /**
     * 查询费用类型管理
     * 
     * @param feeItemId 费用类型管理主键
     * @return 费用类型管理
     */
    @Override
    public BizFinancialFeeItems selectBizFinancialFeeItemsByFeeItemId(Long feeItemId)
    {
        return bizFinancialFeeItemsMapper.selectBizFinancialFeeItemsByFeeItemId(feeItemId);
    }

    /**
     * 查询费用类型管理列表
     * 
     * @param bizFinancialFeeItems 费用类型管理
     * @return 费用类型管理
     */
    @Override
    public List<BizFinancialFeeItems> selectBizFinancialFeeItemsList(BizFinancialFeeItems bizFinancialFeeItems)
    {
        return bizFinancialFeeItemsMapper.selectBizFinancialFeeItemsList(bizFinancialFeeItems);
    }

    /**
     * 新增费用类型管理
     * 
     * @param bizFinancialFeeItems 费用类型管理
     * @return 结果
     */
    @Override
    public int insertBizFinancialFeeItems(BizFinancialFeeItems bizFinancialFeeItems)
    {
        bizFinancialFeeItems.setCreateTime(DateUtils.getNowDate());
        bizFinancialFeeItems.setCreateBy(SecurityUtils.getLoginUser().getSysUser().getNickName());
        bizFinancialFeeItems.setUserId(SecurityUtils.getUserId());
        bizFinancialFeeItems.setDeptId(SecurityUtils.getLoginUser().getSysUser().getDeptId());
        int result = bizFinancialFeeItemsMapper.insertBizFinancialFeeItems(bizFinancialFeeItems);
        return result;
    }

    /**
     * 修改费用类型管理
     * 
     * @param bizFinancialFeeItems 费用类型管理
     * @return 结果
     */
    @Override
    public int updateBizFinancialFeeItems(BizFinancialFeeItems bizFinancialFeeItems)
    {
        bizFinancialFeeItems.setUpdateTime(DateUtils.getNowDate());
        bizFinancialFeeItems.setUpdateBy(SecurityUtils.getLoginUser().getSysUser().getNickName());
        int result = bizFinancialFeeItemsMapper.updateBizFinancialFeeItems(bizFinancialFeeItems);
        return result;
    }

    /**
     * 批量删除费用类型管理
     * 
     * @param feeItemIds 需要删除的费用类型管理主键
     * @return 结果
     */
    @Override
    public int deleteBizFinancialFeeItemsByFeeItemIds(Long[] feeItemIds)
    {
        int result = bizFinancialFeeItemsMapper.deleteBizFinancialFeeItemsByFeeItemIds(feeItemIds);
        return result;
    }

    /**
     * 删除费用类型管理信息
     * 
     * @param feeItemId 费用类型管理主键
     * @return 结果
     */
    @Override
    public int deleteBizFinancialFeeItemsByFeeItemId(Long feeItemId)
    {
        int result = bizFinancialFeeItemsMapper.deleteBizFinancialFeeItemsByFeeItemId(feeItemId);
        return result;
    }

    /**
     * 查询所有费用类型管理列表
     * 
     * @return 费用类型管理集合
     */
    @Override
    public List<BizFinancialFeeItems> selectAllBizFinancialFeeItems()
    {
        return bizFinancialFeeItemsMapper.selectBizFinancialFeeItemsList(new BizFinancialFeeItems());
    }
}
